@@ -5,7 +5,7 @@
  * This file contains the implementation of the main KBiff
  * widget
  *
- * $Id: kbiff.cpp,v 1.2 2001/03/24 18:50:21 gran Exp $
+ * $Id: kbiff.cpp,v 1.3 2001/05/21 21:54:38 gran Exp $
  */
 #include "kbiff.h"
 #include <qmovie.h>
@@ -17,6 +17,7 @@
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <klocale.h>
+#include <kmessagebox.h>
 #include <kprocess.h>
 #include <kwin.h>
 
@@ -121,21 +122,23 @@ void KBiff::processSetup(const KBiffSetup* setup, bool run)
     delete setup;
 }
 
-void KBiff::setMailboxList(const QList<KBiffURL>& mailbox_list, unsigned int poll)
+void KBiff::setMailboxList(const QList<KBiffMailbox>& mailbox_list, unsigned int poll)
 {
-    QList<KBiffURL> tmp_list = mailbox_list;
+    QList<KBiffMailbox> tmp_list = mailbox_list;
 
     myMUTEX = true;
     if (isRunning())
         stop();
     monitorList.clear();
     
-    KBiffURL *url;
-    for (url = tmp_list.first(); url != 0; url = tmp_list.next())
+    KBiffMailbox *mbox;
+    for (mbox = tmp_list.first(); mbox != 0; mbox = tmp_list.next())
     {
+        KBiffURL *url = &(mbox->url);
         KBiffMonitor *monitor = new KBiffMonitor();
         monitor->setMailbox(*url);
         monitor->setPollInterval(poll);
+        monitor->setMailboxKey(mbox->key);
         connect(monitor, SIGNAL(signal_newMail(const int, const QString&)),
                 this, SLOT(haveNewMail(const int, const QString&)));
         connect(monitor, SIGNAL(signal_currentStatus(const int, const QString&, const KBiffMailState)),
@@ -143,6 +146,8 @@ void KBiff::setMailboxList(const QList<KBiffURL>& mailbox_list, unsigned int pol
         connect(monitor, SIGNAL(signal_noMail()), this, SLOT(displayPixmap()));
         connect(monitor, SIGNAL(signal_oldMail()), this, SLOT(displayPixmap()));
         connect(monitor, SIGNAL(signal_noConn()), this, SLOT(displayPixmap()));
+        connect(monitor, SIGNAL(signal_invalidLogin(const QString&)),
+                this, SLOT(invalidLogin(const QString&)));
         monitorList.append(monitor);
     }
     myMUTEX = false;
@@ -265,7 +270,7 @@ void KBiff::popupStatus()
         KBiffMonitor *monitor;
         for(monitor = monitorList.first(); monitor; monitor = monitorList.next())
         {
-            statusList.append(new KBiffStatusItem(monitor->getMailbox(), monitor->newMessages()));
+            statusList.append(new KBiffStatusItem(monitor->getMailboxKey(), monitor->newMessages()));
         }
         statusChanged = false;
     }
@@ -889,3 +894,14 @@ void KBiff::registerMe(DCOPClient *client)
         client->registerAs(QCString(proxy));
     }
 }
+
+void KBiff::invalidLogin(const QString& mailbox)
+{
+  QString title(i18n("Invalid Login to %1").arg(mailbox));
+  KMessageBox::sorry(0,
+    i18n("I was not able to login to the remote server.\n"
+         "This means that either the server is down or you have "
+         "entered an incorrect username or password.\n"
+         "Please make sure that you have entered the correct settings."),
+    title);
+}
