@@ -1,11 +1,11 @@
 /*
  * kbiffmonitor.cpp
- * Copyright (C) 1999 Kurt Granroth <granroth@kde.org>
+ * Copyright (C) 1999-2001 Kurt Granroth <granroth@kde.org>
  *
  * This file contains the implementation of KBiffMonitor and
  * associated classes.
  *
- * $Id: kbiffmonitor.cpp,v 1.2 2001/03/24 18:50:21 gran Exp $
+ * $Id: kbiffmonitor.cpp,v 1.3 2001/05/21 21:54:38 gran Exp $
  */
 #include "kbiffmonitor.h"
 
@@ -39,7 +39,6 @@
 #include <qdatetime.h>
 #include <ksimpleconfig.h>
 
-
 #define MAXSTR (1024)
 
 #define MAIL_STATE_FILE "kbiffstate"
@@ -58,6 +57,7 @@ KBiffMonitor::KBiffMonitor()
       started(false),
       newCount(0),
       oldCount(0),
+      key(""),
       simpleURL(""),
       protocol(""),
       mailbox(""),
@@ -107,7 +107,7 @@ void KBiffMonitor::readConfig()
     config->setDollarExpansion(false);
 
     QString group;
-    group = mailbox + "(" + simpleURL + ")";
+    group = mailbox + "(" + key + ")";
     config->setGroup(group);
 
     QStrList list;
@@ -145,7 +145,7 @@ void KBiffMonitor::saveConfig()
     config->setDollarExpansion(false);
 
     QString group;
-    group = mailbox + "(" + simpleURL + ")";
+    group = mailbox + "(" + key + ")";
     config->setGroup(group);
 
     QStringList uidlist;
@@ -370,6 +370,11 @@ void KBiffMonitor::setPassword(const QString& pass)
     password = pass;
 }
 
+void KBiffMonitor::setMailboxKey(const QString& k)
+{
+    key = k;
+}
+
 void KBiffMonitor::timerEvent(QTimerEvent *)
 {
     emit(signal_checkMail());
@@ -437,7 +442,7 @@ void KBiffMonitor::checkPop()
         if (pop->command(command) == false)
         {
             pop->close();
-            determineState(NoConn);
+            invalidLogin();
             return;
         }
 
@@ -445,7 +450,7 @@ void KBiffMonitor::checkPop()
         if (pop->command(command) == false)
         {
             pop->close();
-            determineState(NoConn);
+            invalidLogin();
             return;
         }
     }
@@ -491,7 +496,7 @@ void KBiffMonitor::checkImap()
     {
         if (imap->connectSocket(server, port) == false)
         {
-            determineState(NoConn);
+            invalidLogin();
             return;
         }
 
@@ -499,7 +504,11 @@ void KBiffMonitor::checkImap()
     }
     
     // imap allows spaces in usernames... we need to take care of that
-    user = imap->mungeUser(user);
+    user = imap->mungeUserPass(user);
+
+    // also asterisks (*) in passwords. maybe it's a good idea
+    // to _always_ munge the user and the password.
+    password = imap->mungeUserPass(password);
 
     // if we are preauthorized OR we want to keep the session alive, then
     // we don't login.  Otherwise, we do.
@@ -507,7 +516,10 @@ void KBiffMonitor::checkImap()
     {
         command = QString().setNum(seq) + " LOGIN " + user + " " + password + "\r\n";
         if (imap->command(command, seq) == false)
+        {
+            invalidLogin();
             return;
+        }
         seq++;
     }
 
@@ -868,7 +880,7 @@ void KBiffMonitor::determineState(unsigned int size)
         {
             mailState = NewMail;
             emit(signal_newMail());
-            emit(signal_newMail(newCount, simpleURL));
+            emit(signal_newMail(newCount, key));
             onStateChanged();
         }
         new_lastSize = size;
@@ -935,17 +947,15 @@ void KBiffMonitor::determineState(KBiffUidlList uidl_list)
         messages++;
     }
 
-    // put this before the emit.  don't know why it matters... but it
-    // apparently does on some systems!
-
-    // if there are any new messages, then notify
-    if (messages > 0)
+    // if there are any new messages, then notify.. but only if the
+    // state isn't currently NewMail
+    if ((messages > 0) && (mailState != NewMail))
     {
       if (!b_new_uidlList || newCount < (int)messages)
       {
         mailState = NewMail;
         emit(signal_newMail());
-        emit(signal_newMail(newCount, simpleURL));
+        emit(signal_newMail(newCount, key));
         onStateChanged();
       }
       newCount = messages;
@@ -969,7 +979,7 @@ void KBiffMonitor::determineState(KBiffMailState state)
     {
         mailState = NewMail;
         emit(signal_newMail());
-        emit(signal_newMail(newCount, simpleURL));
+        emit(signal_newMail(newCount, key));
         onStateChanged();
     }
     else
@@ -1029,7 +1039,7 @@ void KBiffMonitor::determineState(unsigned int size, const QDateTime& last_read,
         mailState = NewMail;
         // Let the world know of the new state
         emit(signal_newMail());
-        emit(signal_newMail(1, simpleURL));
+        emit(signal_newMail(1, key));
         onStateChanged();
       }
       new_lastSize = size;
@@ -1175,6 +1185,16 @@ int KBiffMonitor::mboxMessages()
     return count;
 }
 
+void KBiffMonitor::invalidLogin()
+{
+  // first, we stop this monitor to be on the safe side
+  stop();
+  determineState(NoConn);
+  newCount = -1;
+
+  emit(signal_invalidLogin(key));
+}
+
 ///////////////////////////////////////////////////////////////////////////
 // KBiffSocket
 ///////////////////////////////////////////////////////////////////////////
@@ -1420,7 +1440,10 @@ bool KBiffImap::command(const QString& line, unsigned int seq)
     int len, match;
 
     if (writeLine(line) <= 0)
+    {
+        close();
         return false;
+    }
 
     QString ok, bad, no, response;
     ok.sprintf("%d OK", seq);
@@ -1430,16 +1453,13 @@ bool KBiffImap::command(const QString& line, unsigned int seq)
     {
         // if an error has occurred, we get a null string in return
         if (response.isNull())
-            return false;
+            break;
 
         // if the response is either good or bad, then return
         if (response.find(ok) > -1)
             return true;
         if ((response.find(bad) > -1) || (response.find(no) > -1))
-        {
-            close();
-            return false;
-        }
+            break;
 
         // check the number of messages
         QRegExp messages_re("MESSAGES [0-9]*");
@@ -1456,21 +1476,16 @@ bool KBiffImap::command(const QString& line, unsigned int seq)
     return false;
 }
 
-QString KBiffImap::mungeUser(const QString& old_user)
+QString KBiffImap::mungeUserPass(const QString& old_user)
 {
-    if (old_user.contains(' ') > 0)
-    {
-        QString new_user(old_user);
+    QString new_user(old_user);
 
-        if (new_user.left(1) != "\"")
-            new_user.prepend("\"");
-        if (new_user.right(1) != "\"")
-            new_user.append("\"");
+    if (new_user.left(1) != "\"")
+        new_user.prepend("\"");
+    if (new_user.right(1) != "\"")
+        new_user.append("\"");
 
-        return new_user;
-    }
-    else
-        return old_user;
+    return new_user;
 }
 
 ///////////////////////////////////////////////////////////////////////////
