@@ -1,8 +1,8 @@
 /*
  * kbiffmonitor.h
- * Copyright (C) 1999 Kurt Granroth <granroth@kde.org>
+ * Copyright (C) 1999-2001 Kurt Granroth <granroth@kde.org>
  *
- * $Id: kbiffmonitor.h,v 1.2 2001/03/24 18:50:21 gran Exp $
+ * $Id: kbiffmonitor.h,v 1.3 2001/05/21 21:54:38 gran Exp $
  *
  */
 #ifndef KBIFFMONITOR_H
@@ -12,7 +12,7 @@
 #include <config.h>
 #endif
 #ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>		// Needed on some systems.
+#include <sys/select.h> // Needed on some systems.
 #endif
 
 #include <sys/time.h>
@@ -89,7 +89,7 @@ public:
     virtual ~KBiffImap();
 
     bool command(const QString& line, unsigned int seq);
-    QString mungeUser(const QString& old_user);
+    QString mungeUserPass(const QString& old_user);
 };
 
 /**
@@ -164,7 +164,7 @@ typedef enum
  *
  * @short A "biff" class that monitors local and remote mailboxes
  * @author Kurt Granroth <granroth@kde.org>
- * @version $Id: kbiffmonitor.h,v 1.2 2001/03/24 18:50:21 gran Exp $
+ * @version $Id: kbiffmonitor.h,v 1.3 2001/05/21 21:54:38 gran Exp $
  */
 class KBiffMonitor : public QObject
 {
@@ -189,10 +189,15 @@ public:
     KBiffMailState getMailState() const { return mailState; }
 
     /**
-     * Returns the current mailbox being monitored
+     * Returns the simpleURL of current mailbox being monitored
      */
     const QString getMailbox() const { return simpleURL; }
 
+    /**
+     * Sets or Returns the key of current mailbox being monitored
+     */
+    const QString getMailboxKey() const { return key; }
+
     /**
      * Returns the type of mailbox being monitored
      */
@@ -254,6 +259,7 @@ public slots:
      * Overloaded for convenience
      */
     void setMailbox(const QString& url);
+    void setMailboxKey(const QString& k);
 
     /**
      * Sets the password for the POP3 and IMAP4 protocols.
@@ -316,17 +322,17 @@ signals:
      */
     void signal_oldMail(const QString& mailbox);
 
-	/**
-	 * This will get <CODE>emit</CODE>ed when no connection can be
-	 * established
-	 */
-	void signal_noConn();
-		 
-	/**
-	 * This will get <CODE>emit</CODE>ed when no connection can
-	 * be established
-	 */
-	void signal_noConn(const QString& mailbox);
+   /**
+    * This will get <CODE>emit</CODE>ed when no connection can be
+    * established
+    */
+    void signal_noConn();
+               
+   /**
+    * This will get <CODE>emit</CODE>ed when no connection can
+    * be established
+    */
+    void signal_noConn(const QString& mailbox);
 
     /**
      * This will get <CODE>emit</CODE>ed everytime the mailbox
@@ -341,6 +347,12 @@ signals:
      */
     void signal_currentStatus(const int, const QString& , const KBiffMailState);
 
+    /**
+     * This will get <CODE>emit</CODE>ed everytime there was an
+     * invalid login or incomplete connection to a remote server.
+     */
+    void signal_invalidLogin(const QString& mailbox);
+
 protected:
     void timerEvent(QTimerEvent *);
 
@@ -364,6 +376,8 @@ protected:
     void onStateChanged();
     int  mboxMessages();
 
+    void invalidLogin();
+
 private:
     // General stuff
     int     poll;
@@ -373,6 +387,7 @@ private:
     int     oldCount;
 
     // Mailbox stuff
+    QString key;
     QString simpleURL;
     QString protocol;
     QString mailbox;
