@@ -5,7 +5,7 @@
  * This file contains the implementation of the setup dialog
  * class for KBiff.
  *
- * $Id: setupdlg.cpp,v 1.3 2001/03/24 23:32:58 gran Exp $
+ * $Id: setupdlg.cpp,v 1.4 2001/05/21 21:54:38 gran Exp $
  */
 #include "setupdlg.h"
 
@@ -197,7 +197,7 @@ const KBiffURL KBiffSetup::getCurrentMailbox() const
   return mailboxTab->getMailbox();
 }
 
-const QList<KBiffURL> KBiffSetup::getMailboxList() const
+const QList<KBiffMailbox> KBiffSetup::getMailboxList() const
 {
   return mailboxTab->getMailboxList();
 }
@@ -1216,7 +1216,7 @@ void KBiffMailboxTab::readConfig(const QString& profile)
     for (unsigned int i = 0; i < mailbox_list.count(); i+=3)
     {
       KBiffMailbox *mailbox = new KBiffMailbox();
-      QString key(*mailbox_list.at(i));
+      mailbox->key = *mailbox_list.at(i);
       mailbox->url = KBiffURL(*mailbox_list.at(i+1));
       QString password(scramble(*mailbox_list.at(i+2), false));
 
@@ -1228,20 +1228,21 @@ void KBiffMailboxTab::readConfig(const QString& profile)
         mailbox->url.setPass(password);
       }
 
-      QListViewItem *item = new QListViewItem(mailboxes, key);
+      QListViewItem *item = new QListViewItem(mailboxes, mailbox->key);
       item->setPixmap(0, QPixmap(UserIcon("mailbox")));
 
-      mailboxHash->insert(key, mailbox);
+      mailboxHash->insert(mailbox->key, mailbox);
     }
   }
   else
   {
     KBiffMailbox *mailbox = new KBiffMailbox();
+    mailbox->key = i18n("Default");
     mailbox->store = false;
     mailbox->url = defaultMailbox();
-    mailboxHash->insert("Default", mailbox);
+    mailboxHash->insert(mailbox->key, mailbox);
 
-    QListViewItem *item = new QListViewItem(mailboxes, i18n("Default"));
+    QListViewItem *item = new QListViewItem(mailboxes, mailbox->key);
     item->setPixmap(0, QPixmap(UserIcon("mailbox")));
   }
 
@@ -1395,19 +1396,21 @@ const KBiffURL KBiffMailboxTab::getMailbox() const
     return url;
 }
 
-const QList<KBiffURL> KBiffMailboxTab::getMailboxList() const
+const QList<KBiffMailbox> KBiffMailboxTab::getMailboxList() const
 {
-    QList<KBiffURL> url_list;
+    QList<KBiffMailbox> mbox_list;
 
     for (QListViewItem *item = mailboxes->firstChild();
          item;
-          item = item->nextSibling())
+         item = item->nextSibling())
     {
         KBiffMailbox *mailbox = mailboxHash->find(item->text(0));
-        KBiffURL *url = new KBiffURL(mailbox->url);
-        url_list.append(url);
+        // without the next line the key of the first mailbox is lost.
+        // it's a mystery for me
+        mailbox->key = item->text(0);
+        mbox_list.append(mailbox);
     }
-    return url_list;
+    return mbox_list;
 }
 
 void KBiffMailboxTab::slotDeleteMailbox()
@@ -1665,7 +1668,7 @@ KBiffAboutTab::KBiffAboutTab(QWidget *parent)
                       SLOT(homepage(const QString&)));
 
   QLabel *version_label = new QLabel(this);
-  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2001\nKurt Granroth").arg("3.4"));
+  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2001\nKurt Granroth").arg("3.4.2"));
 
   KURLLabel *email_label = new KURLLabel(this);
   email_label->setText("granroth@kde.org");
